html, body {
    background-color: #dee1e2;
}

#wrapper {
    margin-top: 40px;
}

#actions {
    padding-top: 20px;
}

#actions ul {
    padding: 0 25px 0 0;
    margin: 0;
    list-style: none;
}

#actions li {
    float: left;
    margin: 0 2px 0 0;
    padding: 8px 0;
}

#actions li a {
    color: #ffffff;
    text-shadow: 1px 1px 0 #6e797d;
    text-decoration: none;
    font-weight: bold;
    padding: 10px 25px;
    background-color: #959ea2;
    -moz-border-radius-topleft: 6px;
    -moz-border-radius-topright: 6px;
    -webkit-border-top-left-radius: 6px;
    -webkit-border-top-right-radius: 6px;
}

#actions li a:hover {
    text-shadow: 1px 1px 0 #51595c;
    background-color: #6d787c;
}

#content {
    padding-top: 20px;
    background-color: #fff;
    border-top-right-radius: 6px;
    border-bottom-right-radius: 6px;
    border-bottom-left-radius: 6px;
    -moz-border-radius-topright: 6px;
    -moz-border-radius-bottomright: 6px;
    -moz-border-radius-bottomleft: 6px;
    -webkit-border-top-right-radius: 6px;
    -webkit-border-bottom-right-radius: 6px;
    -webkit-border-bottom-left-radius: 6px;
}

#sidebar {
    padding-right: 10px;
}

#sidebar h4 {
    font-weight: bold;
}

#sidebar ul {
    list-style: none;
    padding: 0;
    margin-bottom: 20px;
}

#sidebar li {
    padding: 2px 15px;
}

#sidebar li a {
    text-decoration: none;
    color: #798488;
}

#sidebar li.active {
    background-color: #e7e9ea;
    color: #3f4547;
    -moz-border-radius: 11px;
    -webkit-border-radius: 11px;
    margin-bottom: 2px;
}

#sidebar li.active a {
    color: #3f4547;
    text-shadow: 0 1px 0 #ffffff;
}

#footer {
    float: right;
}

#footer a {
    color: #989898;
    text-shadow: 0 1px 0 #ffffff;
}


/**** index ****/
#feedback {
    padding-left: 10px;
}

#feedback h2 {
    margin: 20px 0 0 0;
}

#feedback hr {
    margin: 0;
}

#feedback table.list {
    border-top: 1px solid #ddd;
}

#feedback td.details p {
    margin-top: 3px;
}

#feedback td.votes {
    font-size: 32px;
    width: 40px;
    font-weight: bold;
}

#feedback td.votes div {
    text-align: center;
    padding: 15px 7px;
    min-width: 35px;
    -moz-border-radius: 6px;
    -webkit-border-radius: 6px;
    background-color: #f2f2f2;
}


#feedback td.feedback-private {
    color: #ff0000;
    background-color: #ffcccc;
    font-weight: bold;
    text-align: center;
}

.feedback-status {
    font-weight: normal;
    font-size: 11px;
    padding: 2px 7px;
    -moz-border-radius: 3px;
    -webkit-border-radius: 3px;
    vertical-align: middle;
    background-color: #d2f4f6;
    color: #326c6f;
}

.feedback-status-accepted {
    background-color: #d8f4ff;
    color: #3a95c4;
}

.feedback-status-done {
    background-color: #e4ffbc;
    color: #499e00;
}

.feedback-status-new {
    background-color: #ffd8d8;
    color: #ff4e4e;
}

.feedback-comments {
    margin-right: 10px;
    font-size: 11px;
}
.feedback-user, .feedback-date {
    font-size: 11px;
    color: #727c82;
}
p.meta {
    margin-bottom: 50px;
}

#feedback td.details p img, #feedback p .feedback-user img {
    vertical-align: middle;
}

#feedback td.details p .avatar, #feedback p .feedback-user .avatar {
    margin: 0 5px;
}

.feedback-type {
    -moz-border-radius: 3px;
    -webkit-border-radius: 3px;
    padding: 3px 8px;
    color: #ffffff;
    font-size: 9px;
    text-transform: uppercase;
    background-color: #219da4;
}

.feedback-type-problem {
    background-color: #ff4e4e;
}
.feedback-type-general {
    background-color: #499e00;
}
.feedback-type-idea {
    background-color: #3a95c4;
}
.feedback-type-wontdo {
    background-color: #a760ff;
}
.feedback-type-question {
    background-color: #009e8e;
}



/**** detail ****/



#feedback div.votes {
    font-size: 32px;
    font-weight: bold;
    text-align: center;
    padding: 15px 7px 10px 7px;
    -moz-border-radius: 6px;
    -webkit-border-radius: 6px;
    background-color: #f2f2f2;
    float: left;
    margin-right: 25px;
}

#feedback p.num-votes {
    font-size: 10px;
    text-align: center;
    color: #747474;
    margin: 5px 0 0 0;
}

#feedback #vote-down {
    margin-right: 2px;
}

#feedback #vote-up, #feedback #vote-down {
    float: left;
}

#feedback #vote-up input, #feedback #vote-down input {
    padding: 5px;
    background-color: #b1b8bb;
    text-shadow: 1px 1px 0 #7a868b;
}

#feedback-detail-heading {
    margin: 0;
    padding: 10px 0 0 0;
}

#feedback-detail-heading .feedback-type {
    margin-right: 10px;
    vertical-align: middle;
}



.message.staff .staff {
    float: left;
    clear: left;
    padding-left: 10px;
    color: #747474;
    font-size: 11px;
}

.message.staff {
    background-color: #f1fbff;
}


#feedback-duplicate {
    margin: 10px 0 20px 0;
    padding: 15px 30px;
    border-style: solid;
    border-width: 2px;
    -moz-border-radius: 8px;
    -webkit-border-radius: 8px;
}


#feedback-duplicate {
    border-color: #cff2b2;
    background-color: #f4ffe9;
}


/*** pagination ***/

.pagination {
    text-align: center;
    font-size: 16px;
    margin-top: 20px;
    color: #828282;
}
.pagination .current {
    margin: 0 20px;
}

#pagination-last-page {
    margin-left: 20px;
}

#pagination-first-page {
    margin-right: 20px;
}

#pagination-last-page, #pagination-first-page {
    color: #999999;
}


/****** lists *******/

table.list {
    width: 100%;
}
table.list h3 {
    font-size: 16px;
    line-height: 16px;
    padding: 0;
}

table.list tr {
    border-width: 1px 0;
    border-color: #f0f1f2;
    border-style: solid;
}
table.list.list-all .closed {
    text-decoration: line-through;
}

table.list td {
    padding: 8px 10px;
    color: #4b4b4b;
}

table.list td img {
    vertical-align: middle;
}

table.list td.title a {
    font-size: 16px;
    font-weight: bold;
}

/**** forms ****/

#id_honeypot {
    display: none;
}

form.vote-button {
    margin: 0;
}

form.vote-button input.button {
    -moz-border-radius: 11px;
    -webkit-border-radius: 11px;
}

form table {
    width: 100%;
}

textarea {
    width: 70%;
    height: 120px;
}

input[type="text"], input[type="password"], textarea {
    margin-bottom: 10px;
    width: 100%;
}

input[type="submit"] {
    border: none;
    padding: 5px 15px;
    font-size: 12px;
    background-color: #69b500;
    text-shadow: 1px 1px 0 #457800;
    color: #ffffff;
}

form td.label {
    width: 200px;
    vertical-align: top;
}

form td.label label {
    padding: 0;
    text-align: left;
}

form td {
    padding-bottom: 5px;
}

form td.label .form-help, .help-text {
    font-size: 11px;
    color: #999999;
    line-height: 12px;
    float: left;
}

form td.field-error input, form td.field-error textarea {
    border-color: #ff8b8b;
}

form td.label .required {
    font-size: 10px;
    color: #999999;
    padding-left: 5px;
    width: 100%;
    float: left;
}

.form-errors {
    color: #ff0000;
    padding: 4px 0 2px 0;
    font-size: 11px;
    line-height: 10px;
}

.form-errors ul {
    padding: 0;
    list-style: none;
}
.form-errors li {
    color: #ff0000;
    font-size: 11px;
    line-height: 10px;
}

.form-cancel {
    margin-left: 15px;
}

/***** comments *****/
div.message .avatar {
    float: left;
    padding: 10px 4px 4px 4px;
    vertical-align: text-bottom;
    line-height: 0;
}
div.message .content {
}
div.message .content .details {
    padding: 0 0 5px 0;
    font-size: 11px;
    font-weight: normal;
    color: #888888;
    vertical-align: top;
    line-height: 11px;
    text-align: left;
}
div.message {
    border-width: 0 0 1px 0;
    border-color: #d9d9d9;
    border-style: solid;
    padding: 5px 0 0 0;
}

div.message-content {
    padding: 10px 40px 10px 100px;
    min-height: 60px;
}

div.content img {
    padding: 2px;
    border: 1px solid #bbb;
}

.comment .details {
    text-align: left;
}