{% extends "djangovoice/feedback_base.html" %}
{% load trans from i18n %}

{% block title %}{% trans "Feedback" %}{% endblock %}

{% block location %}Feedback{% endblock %}

{% block content %}
<h1>{% trans "Feedback" %}</h1>

<form action="{% url djangovoice_submit %}" method="post">
    {% csrf_token %}
    <table>
        {% for field in form %}
        {% include "djangovoice/includes/fields.html" %}
        {% endfor %}
        <tr>
            <td></td>
            <td><input type="submit" value="{% trans "Submit" %}" class="btn primary" /></td>
        </tr>
    </table>
</form>
{% endblock %}
